==> openjfx_11.0.2+1.orig.tar.xz: openjdk-jfx-11.0.2-1/modules/javafx.web/src/main/native/Source/WebCore/bindings/java/JavaEventListener.h <==
/*
 * Copyright (c) 2011, 2017, Oracle and/or its affiliates. All rights reserved.
 * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS FILE HEADER.
 *
 * This code is free software; you can redistribute it and/or modify it
 * under the terms of the GNU General Public License version 2 only, as
 * published by the Free Software Foundation.  Oracle designates this
 * particular file as subject to the "Classpath" exception as provided
 * by Oracle in the LICENSE file that accompanied this code.
 *
 * This code is distributed in the hope that it will be useful, but WITHOUT
 * ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
 * FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
 * version 2 for more details (a copy is included in the LICENSE file that
 * accompanied this code).
 *
 * You should have received a copy of the GNU General Public License version
 * 2 along with this work; if not, write to the Free Software Foundation,
 * Inc., 51 Franklin St, Fifth Floor, Boston, MA 02110-1301 USA.
 *
 * Please contact Oracle, 500 Oracle Parkway, Redwood Shores, CA 94065 USA
 * or visit www.oracle.com if you need additional information or have any
 * questions.
 */

#pragma once

#include <WebCore/Event.h>
#include <WebCore/EventListener.h>
#include <WebCore/Node.h>

#include <wtf/Vector.h>
#include <wtf/java/JavaRef.h>

namespace WebCore {

class JavaEventListener final : public EventListener {
public:
    JavaEventListener(const JLObject &listener)
        : EventListener(NativeEventListenerType)
        , m_joListener(listener)
    {
        relaxAdoptionRequirement();
    }

    ~JavaEventListener() override;

    bool operator == (const EventListener&) const override;
    void handleEvent(ScriptExecutionContext& context, Event& event) override;

    JGObject m_joListener;
    static ScriptExecutionContext* scriptExecutionContext();
    bool isJavaEventListener() const override { return true; }
private:
    static Vector<ScriptExecutionContext*> sm_vScriptExecutionContexts;
};

}; // namespace WebCore

==> openjfx_11.0.11+0.orig.tar.xz: openjdk-jfx-11.0.11-0/modules/javafx.web/src/main/native/Source/WebCore/bindings/java/JavaEventListener.h <==
/*
 * Copyright (c) 2011, 2017, Oracle and/or its affiliates. All rights reserved.
 * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS FILE HEADER.
 *
 * This code is free software; you can redistribute it and/or modify it
 * under the terms of the GNU General Public License version 2 only, as
 * published by the Free Software Foundation.  Oracle designates this
 * particular file as subject to the "Classpath" exception as provided
 * by Oracle in the LICENSE file that accompanied this code.
 *
 * This code is distributed in the hope that it will be useful, but WITHOUT
 * ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
 * FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
 * version 2 for more details (a copy is included in the LICENSE file that
 * accompanied this code).
 *
 * You should have received a copy of the GNU General Public License version
 * 2 along with this work; if not, write to the Free Software Foundation,
 * Inc., 51 Franklin St, Fifth Floor, Boston, MA 02110-1301 USA.
 *
 * Please contact Oracle, 500 Oracle Parkway, Redwood Shores, CA 94065 USA
 * or visit www.oracle.com if you need additional information or have any
 * questions.
 */

#pragma once

#include "Event.h"
#include "EventListener.h"
#include "Node.h"

#include <wtf/Vector.h>
#include <wtf/java/JavaRef.h>

namespace WebCore {

class JavaEventListener final : public EventListener {
public:
    JavaEventListener(const JLObject &listener)
        : EventListener(NativeEventListenerType)
        , m_joListener(listener)
    {
        relaxAdoptionRequirement();
    }

    ~JavaEventListener() override;

    bool operator == (const EventListener&) const override;
    void handleEvent(ScriptExecutionContext& context, Event& event) override;

    JGObject m_joListener;
    static ScriptExecutionContext* scriptExecutionContext();
    bool isJavaEventListener() const override { return true; }
private:
    static Vector<ScriptExecutionContext*> sm_vScriptExecutionContexts;
};

}; // namespace WebCore
